//  File: MMEmotor.cpp
//
//  C++ Code for object-oriented interface to Pololu Motor Controller board MD01B
//
//  Gerald Recktenwald, gerry@pdx.edu
//  2013-07-03

//  #include "WProgram.h"
#include "MMEmotor.h"

// --- constructor
MMEmotor::MMEmotor( int PWMpin, int Apin, int Bpin ) {
  _PWMpin = PWMpin;
  _INApin = Apin;
  _INBpin = Bpin;
  
  _hasStarted = false;
  _direction = 0;       //   0 for unset, +1 for forward, -1 for reverse
  _speed = 0;
}

// ------------------------------------------------------------------------------
void MMEmotor::begin() {
    _hasStarted = true; 
}

// ------------------------------------------------------------------------------
void MMEmotor::brake() {
    digitalWrite( _INApin, HIGH );
    digitalWrite( _INBpin, HIGH );
    _direction = 0;
}

// ------------------------------------------------------------------------------
void MMEmotor::off() {
    digitalWrite( _INApin, LOW );
    digitalWrite( _INBpin, LOW );
    _direction = 0;
}

// ------------------------------------------------------------------------------
void MMEmotor::moveAtSpeed(int speedVal) {
  
  int dir;
  // -- Positive speedVal means move forward;  negative speedVal means move in reverse
  if( speedVal>0 ) {
    dir = 1;
    forward(); 
  } else if ( speedVal<0 ) {
    backward();
    dir = -1;
  } else {
    dir = 0;
    brake();
  }
  // -- Limit _speed to range 0 <= _speed <= 255.  Don't use map() because it does
  //    not perform a range check 
  //        _speed = abs(speedVal);       //  Guarantee a positive value
  //        _speed = min(255, _speed);    //  Guarantee a value <= 255
  //    combine into one statement for speed
  _speed = dir*min( 255, abs(speedVal) );
  analogWrite( _PWMpin, _speed );
}

// ------------------------------------------------------------------------------
void MMEmotor::reverse() {
  if ( _direction>0 ) {
    backward();
  } else {
    forward();
  }
}

// ------------------------------------------------------------------------------
void MMEmotor::forward() {
  digitalWrite( _INApin, HIGH );
  digitalWrite( _INBpin, LOW  ); 
  _direction = 1;
}

// ------------------------------------------------------------------------------
void MMEmotor::backward() {
  digitalWrite( _INApin, LOW );
  digitalWrite( _INBpin, HIGH  ); 
  _direction = -1;
}

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// ------------------------------------------------------------------------------
int MMEmotor::getDirection() {
  return(_direction);
}

// ------------------------------------------------------------------------------
int MMEmotor::getSpeed() {
  return(_speed);
}
